@@ -433,18 +433,43 @@ class Node(BaseModel):
     ) -> T.List[NodeModel]:
         resolver = given_resolver or cls.GQL.resolver()
         query_str = resolver.make_add_mutation_str(include_upsert=upsert is not None)
-        variables = {
-            cls.GQL.add_parameter_name: jsonable_encoder(inputs, exclude_unset=True)
-        }
+        exclude_none = False if cls.GQL.payload_node_name else True
+        variables_val = jsonable_encoder(
+            inputs, exclude_unset=True, exclude_none=exclude_none
+        )
+        # remove empty lists, like admin_permissions = []
+        if not cls.GQL.payload_node_name:
+            for vars in variables_val:
+                for k, v in list(vars.items()):
+                    if v == []:
+                        del vars[k]
+        # also remove all empty arrays
+        variables = {cls.GQL.add_parameter_name: variables_val}
         if not cls.GQL.payload_node_name:
             use_query_variables = False
         if upsert is not None:
             variables["upsert"] = upsert
         # print(f"{variables=}, {query_str=}")
         if not use_query_variables:
+            # enums must not have "", so remove them
+            from enum import Enum
+
+            for i, input in enumerate(inputs):
+                enum_lst = [
+                    {k: v} for k, v in input.dict().items() if isinstance(v, Enum)
+                ]
+                print(f"{enum_lst=}")
+                for e_pair in enum_lst:
+                    for k, v in e_pair.items():
+                        variables_val[i][k] = "<REP>" + variables_val[i][k] + "<REP>"
+
             better_query_str = replace_query_variables_in_query_str(
                 query_str=query_str, query_variables=variables
             )
+
+            better_query_str = better_query_str.replace('"<REP>', "").replace(
+                '<REP>"', ""
+            )
             # print(f"{better_query_str=}")
             j = await cls.GQL.dgraph_client.execute(
                 query_str=better_query_str, use_one_time=use_one_time
