@@ -71,6 +71,18 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         print(s)
         return s
 
+    def make_get_query_str_via_query(self, kwargs_d: dict) -> str:
+        kwargs = {k: v for k, v in kwargs_d.items() if v is not None}
+        inner_params = ",".join(
+            [
+                f"{field_name}: {{eq: {json.dumps(jsonable_encoder(val))} }}"
+                for field_name, val in kwargs.items()
+            ]
+        )
+        s = f"{{ {self.query_query_name()}(filter: {{{inner_params}}}){self.gql_fields_str()} }}"
+        print(s)
+        return s
+
     @classmethod
     def get_query_name(cls) -> str:
         function_name = cls.node.GQL.get_function_name
@@ -91,7 +103,19 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return s
 
     def make_add_query_str(self) -> str:
-        s = f"{{ {self.node.GQL.payload_node_name}{self.params_and_fields()} }}"
+        params_and_fields = self.params_and_fields()
+        if self.node.GQL.payload_node_name:
+            s = f"{{ {self.node.GQL.payload_node_name}{params_and_fields} }}"
+        else:
+            s = f"{params_and_fields}"
+        return s
+
+    def make_delete_query_str(self) -> str:
+        fields = self.gql_fields_str()
+        if self.node.GQL.payload_node_name:
+            s = f"{{ {self.node.GQL.payload_node_name}{fields} }}"
+        else:
+            s = f"{fields}"
         return s
 
     def make_add_mutation_str(self, include_upsert: bool) -> str:
@@ -105,9 +129,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         if include_upsert is False:
             upsert_str = ""
             inner_upsert_str = ""
+        add_param_name = self.node.GQL.add_parameter_name
         s = f"""
-            mutation Add{typename}($input: [{add_model_name}!]!{upsert_str}) {{
-                {add_function_name}(input: $input{inner_upsert_str}) {self.make_add_query_str()}
+            mutation Add{typename}(${add_param_name}: [{add_model_name}!]!{upsert_str}) {{
+                {add_function_name}({add_param_name}: ${add_param_name}{inner_upsert_str}) {self.make_add_query_str()}
             }}
         """
         return s
@@ -118,9 +143,22 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         update_function_name = self.node.GQL.update_function_name
         if not (self.node.GQL.patch_model and update_function_name):
             raise GQLException("Update model or update function is missing")
+        update_param_name = self.node.GQL.update_parameter_name
         s = f"""
             mutation Update{typename}($set: {patch_model_name}, $remove: {patch_model_name}, $filter: {typename}Filter!) {{
-                {update_function_name}(input: {{filter: $filter, set: $set, remove: $remove}}) {self.make_add_query_str()}
+                {update_function_name}({update_param_name}: {{filter: $filter, set: $set, remove: $remove}}) {self.make_add_query_str()}
+            }}
+        """
+        return s
+
+    def make_update_mutation_str_edgedb(self) -> str:
+        typename = self.node.GQL.typename
+        update_function_name = self.node.GQL.update_function_name
+        if not (self.node.GQL.patch_model and update_function_name):
+            raise GQLException("Update model or update function is missing")
+        s = f"""
+            mutation Update{typename} {{
+                {update_function_name}(filter: $filter, data: $data) {self.make_delete_query_str()}
             }}
         """
         return s
@@ -134,7 +172,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
         s = f"""
             mutation Delete{typename}($filter: {typename}Filter!) {{
-                {delete_function_name}(filter: $filter) {self.make_add_query_str()}
+                {delete_function_name}(filter: $filter) {self.make_delete_query_str()}
             }}
         """
         return s
@@ -166,6 +204,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return node
 
     async def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
+        if not self.node.GQL.get_function_name:
+            return await self._get_via_query(kwargs_d)
         s = self.make_get_query_str(kwargs_d=kwargs_d)
         res = await self.node.GQL.dgraph_client.execute(query_str=s)
         obj = res["data"][self.get_query_name()]
@@ -173,6 +213,18 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             return self.parse_obj_nested(obj)
         return None
 
+    async def _get_via_query(self, kwargs_d: dict) -> T.Optional[NodeType]:
+        s = self.make_get_query_str_via_query(kwargs_d=kwargs_d)  # TODO change
+        from devtools import debug
+
+        debug(s)
+        res = await self.node.GQL.dgraph_client.execute(query_str=s)
+
+        obj = res["data"][self.query_query_name()]
+        if not obj:
+            return None
+        return self.parse_obj_nested(obj[0])
+
     @staticmethod
     def resolvers_by_typename() -> T.Dict[str, T.Type[Resolver]]:
         d = {}
